# mobile library

LEDBASE=/sys/class/leds
RESET_LEDDIR=${LEDBASE}/Mobile_RESETN
POWER_LEDDIR=${LEDBASE}/Mobile_Power
PWROFF_LEDDIR=${LEDBASE}/Mobile_PWRKEY_OFF
PWRON_LEDDIR=${LEDBASE}/Mobile_PWRKEY_ON
PWRKEY_LEDDIR=${LEDBASE}/Mobile_PWRKEY
KYM11_LEDDIR=${LEDBASE}/KYM1x_Power
USB_HUB_LEDDIR=${LEDBASE}/USB_Hub_Reset


# decode board-model
function detect_machine() {
    local model=`cat /proc/device-tree/model`
    local machine="UNKNOWN"

    case $model in
    *Plum-MA)
        machine=3
        ;;
    *KUMQUAT)
        machine=4
        ;;
    *)
        machine=UNKNOWN
        ;;
    esac

    echo $machine
}

# oneshot led
# led_shot(leddir, delay_on, wait)
function led_shot() {
    local leddir=$1
    local delay_on=$2
    local wait=$3

    if [ ! -e ${leddir} ]; then
        log "LED directory ${leddir} not exists."
        return
    fi

    if [ ! -e ${leddir}/shot ]; then
        echo "oneshot" > ${leddir}/trigger
    fi

    # setup delay_on time
    echo ${delay_on} > ${leddir}/delay_on
    echo 1 > ${leddir}/shot
    sleep ${wait}
}

# LED Off/On
function led_off_on() {
    local leddir=$1
    local time_off=$2

    if [ ! -e ${leddir} ]; then
        log "LED directory ${leddir} not exists."
        return
    fi

    echo 0 > ${leddir}/brightness
    sleep ${time_off}
    echo 1 > ${leddir}/brightness
}

function log() {
    local msg=$1
    logger -t mobile_reset $msg
    echo $msg
}

function detect_module() {
    local module="UNKNOWN"

    if [ -e /tmp/.lisa_found ]; then
        module="LISA-U200"
    elif [ -e /tmp/.kym11_found ]; then
        module="KYM11"
    elif [ -e /tmp/.kym12_found ]; then
        module="KYM12"
    elif [ -e /tmp/.um03ko_found ]; then
        module="UM03KO"
    elif [ -e /tmp/.amp520_found ]; then
        module="AMP520"
    elif [ -e /tmp/.amm570_found ]; then
        module="AMM570"
    fi

    echo $module
}

function detect_module_by_id() {
    local xioid="0"
    local module="UNKNOWN"
    local machine=`detect_machine`

    for x in `cat /proc/cmdline`; do
        case $x in
        xio_id=*)
            xioid="${x#xio_id=}"
            ;;
        esac
    done

    case ${machine}_${xioid} in
    # LISA-U200
    3_2 | 3_3 | 3_4 | 3_7 | 3_8 | 3_9 | 3_10 | 3_15 | 3_16 )
        module="LISA-U200"
        ;;
    # KYM11
    3_6 | 3_11 | 3_18 | 3_21 )
        module="KYM11"
        ;;
    # KYM12
    3_41 )
        module="KYM12"
        ;;
    # UM03KO"
    3_12 )
        module="UM03KO"
        ;;
    # AMP520
    3_13 | 3_14 | 3_19 | 3_20 | 3_22 | 3_23 | 3_29 )
        module="AMP520"
        ;;
    # AMM570
    3_34 | 3_39 | 4_2 )
        module="AMM570"
        ;;
    esac

    echo $module
}
